AppConfig class

Properties

appInfo ↔ AppInfo
getter/setter pair
appInUse ↔ AppInUse
getter/setter pair
appVersion ↔ String
getter/setter pair
authStatus ↔ AuthStatus
getter/setter pair
buildNumber ↔ int
getter/setter pair
defaultItemlistType ↔ ItemlistType
getter/setter pair
hasEarlyAccess ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isAdminMode ↔ bool
getter/setter pair
isGuestMode ↔ bool
getter/setter pair
lastStableBuild ↔ int
getter/setter pair
lastStableVersion ↔ String
getter/setter pair
promoEndpoints ↔ Map<AppInUse, String>
getter/setter pair
promoSources ↔ List<AppInUse>
getter/setter pair
releaseItemlists ↔ Map<String, Itemlist>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showBetaFeatures ↔ bool
getter/setter pair
timelinePromoFrequency ↔ int
getter/setter pair

Methods

initialize({required AppInUse app}) → Future<void>
Inicialización manual para controlar mejor el ciclo de vida
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
selectRootPage({required Widget rootPage, required Widget? homePage, required Widget splashPage, required dynamic previousVersionPage, required Widget onGoingPage}) → Widget
setPromoSources({List<AppInUse> promoSources = const [], int timelinePromoFrequency = 5}) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → AppConfig
no setter
logger → Logger
final