GeoLocatorController class

Implemented types

Constructors

GeoLocatorController()

Properties

areaSuggestions → Set<String>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAddressSimple(Position currentPos) → Future<String>
override
getCurrentPosition() → Future<Position?>
override
getMultiplePlacemarks(List<Position> positions) → Future<List<Placemark>>
getNearbySimpleAddresses(Position currentPos, {int numberOfSuggestions = 10}) → Future<List<String>>
getPlaceMark(Position currentPos) → Future<Placemark>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestPermission() → Future<LocationPermission>
override
toString() → String
A string representation of this object.
inherited
updateLocation(String profileId, Position? currentPosition) → Future<Position?>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited