SubscriptionController class
- Inheritance
-
- Implemented types
-
Methods
-
addListener(SintStateUpdate listener)
→ Disposer
-
Register a closure to be called when the object notifies its listeners.
inherited
-
addListenerId(Object? key, SintStateUpdate listener)
→ Disposer
-
inherited
-
cancelSubscription()
→ Future<void>
-
override
-
changeSubscriptionPlan(String planId)
→ void
-
override
-
containsListener(SintStateUpdate listener)
→ bool
-
inherited
-
debounce<T>(RxInterface<T> rx, void callback(T), {Duration duration = const Duration(milliseconds: 400)})
→ void
-
Calls
callback after rx stops changing for duration.
Useful for search-as-you-type, form validation, etc.
inherited
-
dispose()
→ void
-
inherited
-
ever<T>(RxInterface<T> rx, void callback(T))
→ void
-
Calls
callback every time rx changes.
Auto-cancels on controller disposal.
inherited
-
getActiveSubscriptions({SubscriptionLevel? targetLevel, int? targetMonth, int? targetYear})
→ List<UserSubscription>
-
override
-
getSubscriptionPrice(SubscriptionLevel level)
→ double
-
override
-
initializeSubscriptions()
→ Future<void>
-
override
-
interval<T>(RxInterface<T> rx, void callback(T), {Duration duration = const Duration(seconds: 1)})
→ void
-
Calls
callback at most once per duration, ignoring
intermediate changes. Useful for rate-limiting UI updates.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
once<T>(RxInterface<T> rx, void callback(T))
→ void
-
Calls
callback only the first time rx changes, then cancels.
inherited
-
onClose()
→ void
-
Called before onDelete method. onClose might be used to
dispose resources used by the controller. Like closing events,
or streams before the controller is destroyed.
Or dispose objects that can potentially create some memory leaks,
like TextEditingControllers, AnimationControllers.
Might be useful as well to persist some data on disk.
inherited
-
onDelete()
→ void
-
inherited
-
onInit()
→ void
-
Called immediately after the widget is allocated in memory.
You might use this to initialize something for the controller.
override
-
onReady()
→ void
-
Called 1 frame after onInit(). It is the perfect place to enter
navigation events, like snackbar, dialogs, or a new route, or
async request.
override
-
onStart()
→ void
-
Called at the exact moment the widget is allocated in memory.
It uses an internal "callable" type, to avoid any @overrides in subclasses.
This method should be internal and is required to define the
lifetime cycle of the subclass.
inherited
-
paySubscription(SubscriptionPlan subscriptionPlan, String fromRoute)
→ Future<void>
-
override
-
refresh()
→ void
-
inherited
-
refreshActiveSubscriptions()
→ Future<void>
-
override
-
refreshGroup(Object id)
→ void
-
inherited
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that the
object notifies.
inherited
-
removeListenerId(Object id, VoidCallback listener)
→ void
-
inherited
-
reportAdd(VoidCallback disposer)
→ void
-
inherited
-
reportRead()
→ void
-
inherited
-
selectFacilityType(FacilityType type)
→ void
-
override
-
selectPlaceType(PlaceType type)
→ void
-
override
-
selectProfileType(ProfileType type)
→ void
-
override
-
setActiveSubscriptions()
→ Future<void>
-
override
-
setProfileTypePlans()
→ void
-
override
-
toString()
→ String
-
A string representation of this object.
inherited
-
update([List<Object>? ids, bool condition = true])
→ void
-
Notifies listeners to update the UI.
inherited
-
updateProfileType()
→ Future<void>
-
override