UserController class

Inheritance
Implemented types

Constructors

UserController()

Properties

collective Collective
getter/setter pairoverride
currentItemlistType ItemlistType?
no setteroverride
fcmToken String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
initialized bool
Checks whether the controller has already been initialized.
no setterinherited
isClosed bool
Checks whether the controller has already been closed.
no setterinherited
isDisposed bool
no setterinherited
isNewUser bool
no setteroverride
isSubscriptionSuspended bool
no setter
itemlistOwnerType OwnerType
getter/setter pairoverride
listenersLength int
no setterinherited
newProfile AppProfile
getter/setter pairoverride
profile AppProfile
getter/setter pairoverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscriptionLevel SubscriptionLevel
no setteroverride
user AppUser
getter/setter pairoverride
userFirestore UserFirestore
getter/setter pair
userSubscription UserSubscription?
getter/setter pairoverride

Methods

addBoughtItem(String itemId) Future<void>
override
addListener(SintStateUpdate listener) → Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId(Object? key, SintStateUpdate listener) → Disposer
inherited
addOrderId(String orderId) Future<void>
override
changeProfile(AppProfile selectedProfile) Future<void>
override
clear() → void
containsListener(SintStateUpdate listener) bool
inherited
createProfile() Future<void>
override
createUser() Future<void>
override
debounce<T>(RxInterface<T> rx, void callback(T), {Duration duration = const Duration(milliseconds: 400)}) → void
Calls callback after rx stops changing for duration. Useful for search-as-you-type, form validation, etc.
inherited
dispose() → void
inherited
ever<T>(RxInterface<T> rx, void callback(T)) → void
Calls callback every time rx changes. Auto-cancels on controller disposal.
inherited
getProfiles() Future<void>
override
getUserFromFacebook(String fbAccessToken) Future<void>
override
getUserFromFirebase(User fbaUser) → void
Create user profile from google login
override
getUserSubscription() Future<void>
override
goingToEvent(String eventId) → void
override
interval<T>(RxInterface<T> rx, void callback(T), {Duration duration = const Duration(seconds: 1)}) → void
Calls callback at most once per duration, ignoring intermediate changes. Useful for rate-limiting UI updates.
inherited
loadProfileChambers() Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
once<T>(RxInterface<T> rx, void callback(T)) → void
Calls callback only the first time rx changes, then cancels.
inherited
onClose() → void
Called before onDelete method. onClose might be used to dispose resources used by the controller. Like closing events, or streams before the controller is destroyed. Or dispose objects that can potentially create some memory leaks, like TextEditingControllers, AnimationControllers. Might be useful as well to persist some data on disk.
inherited
onDelete() → void
inherited
onInit() → void
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
override
onReady() → void
Called 1 frame after onInit(). It is the perfect place to enter navigation events, like snackbar, dialogs, or a new route, or async request.
override
onStart() → void
Called at the exact moment the widget is allocated in memory. It uses an internal "callable" type, to avoid any @overrides in subclasses. This method should be internal and is required to define the lifetime cycle of the subclass.
inherited
refresh() → void
inherited
refreshGroup(Object id) → void
inherited
reloadProfileItemlists() Future<void>
override
removeAccount() Future<void>
override
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
removeListenerId(Object id, VoidCallback listener) → void
inherited
removeProfile() Future<void>
override
reportAdd(VoidCallback disposer) → void
inherited
reportRead() → void
inherited
setCurrentItemlistType(ItemlistType? type) → void
override
setIsVerified(bool isVerified) Future<void>
override
setNewProfileInfo() → void
setUserByEmail(String userEmail) Future<void>
override
setUserById(String userId) Future<void>
override
setUserSubscription(UserSubscription subscription) Future<void>
override
stopGoingToEvent(String eventId) → void
override
toString() String
A string representation of this object.
inherited
update([List<Object>? ids, bool condition = true]) → void
Notifies listeners to update the UI.
inherited
updateCustomerId(String customerId) Future<void>
override
updatePhoneNumber(String phone, String countryCode) Future<bool>
override
updateSubscriptionId(String subscriptionId) Future<void>
override
verifyLocation() Future<void>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited