ActivityFeed class

Constructors

ActivityFeed({String id = "", String ownerId = "", String profileId = "", String profileName = "", String profileImgUrl = "", String message = "", String activityReferenceId = "", ActivityFeedType? activityFeedType, String mediaUrl = "", int createdTime = 0, bool unread = true})
ActivityFeed.fromAppBot({required String toProfileId, required dynamic referenceId, required ActivityFeedType type, String message = '', String mediaUrl = ''})
ActivityFeed.fromComment({required PostComment comment, required ActivityFeedType type, AppProfile? fromProfile, String? mediaUrl})
ActivityFeed.fromEvent({required Event event, required AppProfile fromProfile, required ActivityFeedType type, String msg = ''})
ActivityFeed.fromGameRequest({required AppRequest request, required AppProfile senderProfile, required ActivityFeedType type, String message = ''})
Factory for game invitations using AppRequest
ActivityFeed.fromGameRequestResponse({required AppRequest request, required AppProfile responderProfile, required ActivityFeedType type, String message = ''})
Factory for game invitation responses (accepted/declined)
ActivityFeed.fromGlobalNewRelease({required String releaseId, required String releaseTitle, required String releaseCoverUrl, required AppProfile authorProfile})
Factory for GLOBAL new release notifications. These are stored in globalActivityFeed collection and downloaded by all users. releaseId - ID of the release releaseTitle - Title of the release releaseCoverUrl - Cover image URL authorProfile - Profile of the author who published the release
ActivityFeed.fromJSON(dynamic data)
ActivityFeed.fromNewBlogEntry({required BlogEntry blogEntry, required AppProfile authorProfile, required String followerId})
Factory for new BlogEntry notifications to followers (new model).
ActivityFeed.fromNewBlogPost({required Post blogPost, required AppProfile authorProfile, required String followerId})
Factory for new blog post notifications to followers
ActivityFeed.fromPost({required Post post, required AppProfile fromProfile, required ActivityFeedType type, String msg = ''})
ActivityFeed.fromReleaseApprovalRequest({required String adminProfileId, required AppRequest request, required AppProfile authorProfile, String releaseCoverUrl = ''})
Factory for release approval request notifications (sent to admins). adminProfileId - Profile ID of the admin who will review request - The AppRequest for release approval authorProfile - Profile of the author submitting the release releaseCoverUrl - Cover image URL of the release
ActivityFeed.fromReleaseApprovalResponse({required AppRequest request, required bool isApproved, String reviewerMessage = ''})
Factory for release approval/rejection notifications (sent to author). request - The AppRequest for release approval isApproved - Whether the release was approved or rejected reviewerMessage - Optional message from reviewer
ActivityFeed.fromRequest({required AppRequest request, required ActivityFeedType type, required AppProfile fromProfile, String mediaUrl = '', bool isResponse = false, bool isEvent = true, String? message})

Properties

activityFeedType ActivityFeedType?
getter/setter pair
activityReferenceId String
getter/setter pair
createdTime int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
mediaUrl String
getter/setter pair
message String
getter/setter pair
ownerId String
getter/setter pair
profileId String
Owner of activity feed
getter/setter pair
profileImgUrl String
getter/setter pair
profileName String
Reference to profile if needed
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unread bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() Map<String, dynamic>
toJSONWithId() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited