Address class

Constructors

Address({String country = "", String state = "", String city = "", String neighborhood = "", String street = "", String placeNumber = "", String zipCode = ""})
Address.fromJSON(dynamic data)

Properties

city ↔ String
getter/setter pair
country ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
neighborhood ↔ String
getter/setter pair
placeNumber ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String
getter/setter pair
street ↔ String
getter/setter pair
zipCode ↔ String
getter/setter pair

Methods

getAddressSimple() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited