AppRequest class

Constructors

AppRequest({String id = "", String from = "", String to = "", int createdTime = 0, int expiresAt = 0, EventOffer? newOffer, String message = "", bool unread = true, String eventId = "", String collectiveId = "", String positionRequestedId = "", Instrument? instrument, double percentageCoverage = 0, int distanceKm = 0, RequestDecision requestDecision = RequestDecision.pending, GameRequestType? gameRequestType})
AppRequest.dawInvitation({required String from, required String to, required String projectId, required String projectName, String role = 'musician', String? message})
Create a DAW project collaboration invitation.
factory
AppRequest.fromJSON(dynamic data)
AppRequest.gameInvitation({required String from, required String to, required GameRequestType gameType, String? message, int expirationMinutes = defaultGameExpirationMinutes})
Create a game invitation request
factory
AppRequest.releaseApproval({required String from, required String to, required String releaseItemId, required String releaseName, String? authorName, String? message})
Create a release approval request (for books, songs, etc.) from - profileId of the author submitting the release to - app identifier (e.g., "EMXI", "Gigmeout") for admin review releaseItemId - ID of the AppReleaseItem being submitted releaseName - Name of the release for the message
factory

Properties

collectiveId String
getter/setter pair
createdTime int
getter/setter pair
distanceKm int
getter/setter pair
eventId String
getter/setter pair
expiresAt int
getter/setter pair
from String
getter/setter pair
gameRequestType GameRequestType?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
instrument Instrument?
getter/setter pair
isDawInvitation bool
Check if this is a DAW collaboration invitation.
no setter
isExpired bool
Check if request has expired (for game invitations)
no setter
isGameRequest bool
Check if this is a game request
no setter
isPending bool
Check if request is still pending and not expired
no setter
isReleaseApprovalRequest bool
Check if this is a release approval request Release approval requests have eventId (releaseItemId) and id containing 'release'
no setter
message String
getter/setter pair
newOffer EventOffer?
getter/setter pair
percentageCoverage double
getter/setter pair
positionRequestedId String
getter/setter pair
requestDecision RequestDecision
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeRemaining Duration
Get time remaining until expiration
no setter
to String
getter/setter pair
unread bool
getter/setter pair

Methods

copyWith({String? id, String? from, String? to, String? collectiveId, String? eventId, String? positionRequestedId, int? createdTime, int? expiresAt, EventOffer? newOffer, String? message, bool? unread, Instrument? instrument, double? percentageCoverage, int? distanceKm, RequestDecision? requestDecision, GameRequestType? gameRequestType}) AppRequest
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultDawExpirationDays → const int
Default DAW invitation expiration (7 days).
defaultGameExpirationMinutes → const int
Default game invitation expiration (3 minutes)