isPending property
bool
get
isPending
Check if request is still pending and not expired
Implementation
bool get isPending => requestDecision == RequestDecision.pending && !isExpired;
Check if request is still pending and not expired
bool get isPending => requestDecision == RequestDecision.pending && !isExpired;