AppTransaction class

Constructors

AppTransaction({double amount = 0, TransactionType type = TransactionType.purchase, String? senderId = CoreConstants.appBank, String? recipientId = CoreConstants.appBank, String id = "", String description = "", int createdTime = 0, String? orderId, AppCurrency currency = AppCurrency.appCoin, TransactionStatus status = TransactionStatus.pending, String? secretKey})
VERIFY IF NEEDED
AppTransaction.fromJSON(dynamic data)

Properties

amount ↔ double
getter/setter pair
createdTime ↔ int
getter/setter pair
currency ↔ AppCurrency
getter/setter pair
description ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
orderId ↔ String?
getter/setter pair
recipientId ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretKey ↔ String?
getter/setter pair
senderId ↔ String?
getter/setter pair
status ↔ TransactionStatus
getter/setter pair
type ↔ TransactionType
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited