AppUser class

Constructors

AppUser({String id = "", String name = "", String firstName = "", String lastName = "", int dateOfBirth = 0, String homeTown = "", String phoneNumber = "", String countryCode = "", String password = "", String email = "", String photoUrl = "", UserRole userRole = UserRole.subscriber, bool isVerified = false, bool isBanned = false, String androidNotificationToken = "", List<AppProfile> profiles = const [], List<String> orderIds = const [], String referralCode = "", String couponCode = "", int createdDate = 0, int lastTimeOn = 0, String fcmToken = "", String spotifyToken = "", String currentProfileId = "", String customerId = '', String subscriptionId = ''})
If is not empty, user has minimum a basic plan
AppUser.fromJSON(dynamic data)

Properties

androidNotificationToken ↔ String
getter/setter pair
boughtItems ↔ List<String>?
getter/setter pair
countryCode ↔ String
getter/setter pair
couponCode ↔ String
getter/setter pair
createdDate ↔ int
If user has used a referral coupon code
getter/setter pair
currentProfileId ↔ String
getter/setter pair
customerId ↔ String
getter/setter pair
dateOfBirth ↔ int
getter/setter pair
email ↔ String
getter/setter pair
fcmToken ↔ String
getter/setter pair
firstName ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
homeTown ↔ String
getter/setter pair
id ↔ String
getter/setter pair
isBanned ↔ bool
getter/setter pair
isVerified ↔ bool
getter/setter pair
lastName ↔ String
getter/setter pair
lastTimeOn ↔ int
getter/setter pair
name ↔ String
getter/setter pair
orderIds ↔ List<String>
getter/setter pair
password ↔ String
getter/setter pair
phoneNumber ↔ String
getter/setter pair
photoUrl ↔ String
getter/setter pair
profiles ↔ List<AppProfile>
getter/setter pair
referralCode ↔ String
If user has a coupon code to share
getter/setter pair
releaseItemIds ↔ List<String>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spotifyToken ↔ String
getter/setter pair
subscriptionId ↔ String
Customer Stripe Id for future references
getter/setter pair
userRole ↔ UserRole
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toInvoiceJSON() → Map<String, dynamic>
toJSON() → Map<String, dynamic>
DEPRECATED
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited