BaseItem class

Constructors

BaseItem({String id = '', String name = '', String? description, String imgUrl = '', List<String>? galleryUrls, String url = '', int duration = 0, int state = 0, String permaUrl = '', String ownerId = '', String ownerName = '', int publishedYear = 0, String? metaOwner, List<String> categories = const []})

Properties

categories List<String>
getter/setter pair
description String?
getter/setter pair
duration int
getter/setter pair
galleryUrls List<String>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
imgUrl String
getter/setter pair
metaOwner String?
getter/setter pair
name String
getter/setter pair
ownerId String
getter/setter pair
ownerName String
getter/setter pair
permaUrl String
getter/setter pair
publishedYear int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state int
getter/setter pair
url String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited