CollectiveFile class

A shared file within a collective workspace.

Stored as subcollection collectives/{id}/files/{fileId}. Supports various file types grouped by optional folders.

Constructors

CollectiveFile({String id = '', String collectiveId = '', String name = '', String description = '', String url = '', String thumbnailUrl = '', String fileType = 'other', int fileSize = 0, String uploadedBy = '', String uploaderName = '', String uploaderImgUrl = '', String folder = '', int createdAt = 0})
CollectiveFile.fromJSON(Map<String, dynamic> data)
factory

Properties

collectiveId String
getter/setter pair
createdAt int
getter/setter pair
description String
getter/setter pair
fileSize int
getter/setter pair
fileType String
getter/setter pair
folder String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thumbnailUrl String
getter/setter pair
uploadedBy String
getter/setter pair
uploaderImgUrl String
getter/setter pair
uploaderName String
getter/setter pair
url String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited