CollectiveNote class

A collaborative note/wiki page using Quill Delta format.

Stored as subcollection collectives/{id}/notes/{noteId}.

Constructors

CollectiveNote({String id = '', String collectiveId = '', String title = '', String contentJson = '', String plainText = '', String createdBy = '', String lastEditedBy = '', String lastEditorName = '', int createdAt = 0, int updatedAt = 0, bool isPinned = false, String emoji = ''})
CollectiveNote.fromJSON(Map<String, dynamic> data)
factory

Properties

collectiveId ↔ String
getter/setter pair
contentJson ↔ String
getter/setter pair
createdAt ↔ int
getter/setter pair
createdBy ↔ String
getter/setter pair
emoji ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
isPinned ↔ bool
getter/setter pair
lastEditedBy ↔ String
getter/setter pair
lastEditorName ↔ String
getter/setter pair
plainText ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String
getter/setter pair
updatedAt ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited