CommentReply class

Constructors

CommentReply({String id = "", String profileId = "", String text = "", int likeCount = 0, AppMediaType? mediaType, bool isHidden = false, int createdTime = 0, int modifiedTime = 0})
CommentReply.fromJSON(Map data)

Properties

createdTime ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
isHidden ↔ bool
getter/setter pair
likeCount ↔ int
getter/setter pair
mediaType ↔ AppMediaType?
getter/setter pair
modifiedTime ↔ int
getter/setter pair
profileId ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited