ErpRoleAssignment class

Maps a user to their ERP privileges and executive title. Stored in Firestore erpRoleAssignments collection, keyed by userId.

Constructors

ErpRoleAssignment({String userId = '', String displayName = '', List<ErpPrivilege> privileges = const [], int assignedDate = 0, String assignedBy = ''})
ErpRoleAssignment.fromJSON(Map<String, dynamic> data)

Properties

assignedBy String
getter/setter pair
assignedDate int
getter/setter pair
canExportForecast bool
no setter
canManageSubscriptions bool
no setter
canViewKpis bool
no setter
canViewPayments bool
no setter
displayName String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
privileges List<ErpPrivilege>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String
getter/setter pair

Methods

hasPrivilege(ErpPrivilege privilege) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited