Event class

Constructors

Event({String id = "", String name = "", String description = "", String imgUrl = "", String coverImgUrl = "", String ownerId = '', String ownerName = '', String ownerEmail = '', bool public = true, int createdTime = 0, int eventDate = 0, UsageReason reason = UsageReason.any, List<String>? genres, double itemPercentageCoverage = 0.0, int distanceKm = 0, Price? paymentPrice, Price? coverPrice, EventType type = EventType.rehearsal, EventStatus status = EventStatus.draft, Place? place, Position? position, bool isFulfilled = false, List<AppMediaItem>? appMediaItems, List<InstrumentFulfillment>? instrumentsFulfillment, List<CollectiveFulfillment>? collectivesFulfillment, List<String>? watchingProfiles, List<String>? goingProfiles, bool isOnline = false, String? url, bool isOutdoor = false, bool isTest = false, int guestsLimit = 0, bool isEdited = false, String slug = '', bool isRecurring = false, List<int> recurringDays = const [], String recurringTime = '', String roomId = '', String googleCalendarId = ''})
Event.createBasic(String name, dynamic desc)
Event.fromJSON(dynamic data)

Properties

appMediaItems List<AppMediaItem>?
getter/setter pair
collectivesFulfillment List<CollectiveFulfillment>?
getter/setter pair
coverImgUrl String
getter/setter pair
coverPrice Price?
PAYMENT FOR ARTISTS
getter/setter pair
createdTime int
getter/setter pair
description String
getter/setter pair
distanceKm int
MINIMUM % COVERAGE TO ALLOW SEND REQUEST
getter/setter pair
eventDate int
getter/setter pair
genres List<String>?
getter/setter pair
goingProfiles List<String>?
getter/setter pair
googleCalendarId String
getter/setter pair
guestsLimit int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
imgUrl String
getter/setter pair
instrumentsFulfillment List<InstrumentFulfillment>?
getter/setter pair
isEdited bool
getter/setter pair
isFulfilled bool
getter/setter pair
isOnline bool
getter/setter pair
isOutdoor bool
getter/setter pair
isRecurring bool
getter/setter pair
isTest bool
getter/setter pair
itemPercentageCoverage double
getter/setter pair
name String
getter/setter pair
ownerEmail String
getter/setter pair
ownerId String
getter/setter pair
ownerName String
getter/setter pair
paymentPrice Price?
MAXIMUM DISTANCE TO ALLOW SENDING REQUEST
getter/setter pair
place Place?
getter/setter pair
position ↔ Position?
getter/setter pair
public bool
getter/setter pair
reason UsageReason
getter/setter pair
recurringDays List<int>
getter/setter pair
recurringTime String
getter/setter pair
roomId String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slug String
getter/setter pair
status EventStatus
getter/setter pair
type EventType
COVER PRICE FOR CASUALS
getter/setter pair
url String?
getter/setter pair
watchingProfiles List<String>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generateSlug(String title) String