FanBreakdown class

Aggregated fan breakdown for a creator.

Constructors

FanBreakdown(List<FanSegment> segments)
const

Properties

casualCount int
no setter
fanCount int
no setter
fans List<FanSegment>
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
segments List<FanSegment>
final
superfanCount int
no setter
superfans List<FanSegment>
no setter
supporterCount int
no setter
totalCount int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

empty → const FanBreakdown
Empty breakdown