InboxMessage class

Constructors

InboxMessage({String id = "", String ownerId = "", String profileName = "", String profileImgUrl = "", String text = "", int createdTime = 0, int seenTime = 0, AppMediaType type = AppMediaType.text, String mediaUrl = "", String referenceId = "", int audioDuration = 0, List<String> likedProfiles = const [], bool isPinned = false, String pollId = ""})
InboxMessage.fromJSON(dynamic data)

Properties

audioDuration ↔ int
getter/setter pair
createdTime ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
isPinned ↔ bool
getter/setter pair
likedProfiles ↔ List<String>
getter/setter pair
mediaUrl ↔ String
getter/setter pair
ownerId ↔ String
getter/setter pair
pollId ↔ String
getter/setter pair
profileImgUrl ↔ String
getter/setter pair
profileName ↔ String
getter/setter pair
referenceId ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seenTime ↔ int
getter/setter pair
text ↔ String
getter/setter pair
type ↔ AppMediaType
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited