Influence class

Constructors

Influence({String id = "", String name = "", String thumbnailUrl = ""})
Influence.fromJSON(dynamic data)

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thumbnailUrl String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited