ReadingProgress class

Constructors

ReadingProgress({required String itemId, required String itemName, String itemImgUrl = '', String itemOwnerName = '', int maxPageReached = 0, int totalPages = 0, int sessionCount = 0, int totalReadingTime = 0, int totalPagesRead = 0, Set<int> pagesViewed = const {}, int lastReadTime = 0})
ReadingProgress.fromSessions(String itemId, List<NupaleSession> sessions)
factory

Properties

completionPercent double
no setter
hashCode int
The hash code for this object.
no setterinherited
hasReReads bool
no setter
isComplete bool
no setter
itemId String
final
itemImgUrl String
final
itemName String
final
itemOwnerName String
final
lastReadTime int
final
maxPageReached int
final
pagesViewed Set<int>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionCount int
final
totalPages int
final
totalPagesRead int
final
totalReadingTime int
final

Methods

copyWith({String? itemImgUrl, String? itemOwnerName}) ReadingProgress
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited