Post class

Constructors

Post({String id = '', String ownerId = '', String profileName = '', String profileImgUrl = '', String caption = '', PostType type = PostType.caption, String mediaUrl = '', String thumbnailUrl = '', String externalUrl = '', int createdTime = 0, int modifiedTime = 0, Position? position, String location = '', List<String> likedProfiles = const [], List<String> sharedProfiles = const [], List<String> savedByProfiles = const [], List<String> commentIds = const [], List<PostComment> comments = const [], List<String> hashtags = const [], List<String> mentionedProfiles = const [], bool isCommentEnabled = true, bool isPrivate = false, bool isDraft = false, bool isHidden = false, VerificationLevel? verificationLevel, String referenceId = '', String mediaOwner = '', int lastInteraction = 0, double aspectRatio = 1, String textStyleId = '', String? originalPostId, String? originalOwnerId, int? scheduledTime, bool isScheduled = false, bool isEdited = false, String slug = ''})
Post.createClone(Post post)
Post.fromJSON(dynamic data)

Properties

aspectRatio ↔ double
getter/setter pair
caption ↔ String
getter/setter pair
commentIds ↔ List<String>
getter/setter pair
comments ↔ List<PostComment>
getter/setter pair
createdTime ↔ int
getter/setter pair
externalUrl ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hashtags ↔ List<String>
getter/setter pair
id ↔ String
getter/setter pair
isCommentEnabled ↔ bool
getter/setter pair
isDraft ↔ bool
getter/setter pair
isEdited ↔ bool
getter/setter pair
isHidden ↔ bool
getter/setter pair
isPrivate ↔ bool
getter/setter pair
isScheduled ↔ bool
getter/setter pair
lastInteraction ↔ int
getter/setter pair
likedProfiles ↔ List<String>
getter/setter pair
location ↔ String
getter/setter pair
mediaOwner ↔ String
getter/setter pair
mediaUrl ↔ String
getter/setter pair
mentionedProfiles ↔ List<String>
getter/setter pair
modifiedTime ↔ int
getter/setter pair
originalOwnerId ↔ String?
getter/setter pair
originalPostId ↔ String?
getter/setter pair
ownerId ↔ String
getter/setter pair
position ↔ Position?
getter/setter pair
profileImgUrl ↔ String
getter/setter pair
profileName ↔ String
getter/setter pair
referenceId ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
savedByProfiles ↔ List<String>
getter/setter pair
scheduledTime ↔ int?
getter/setter pair
sharedProfiles ↔ List<String>
getter/setter pair
slug ↔ String
getter/setter pair
textStyleId ↔ String
getter/setter pair
thumbnailUrl ↔ String
getter/setter pair
type ↔ PostType
getter/setter pair
verificationLevel ↔ VerificationLevel?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

generateSlug(String caption) → String