ProfileSkill class
Constructors
- ProfileSkill({String id = '', String name = '', String description = '', ExperienceLevel experienceLevel = ExperienceLevel.beginner, double price = 0})
- ProfileSkill.addBasic(String name)
- ProfileSkill.fromJSON(dynamic data)
Properties
- description ↔ String
-
getter/setter pair
- experienceLevel ↔ ExperienceLevel
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String
-
getter/setter pair
- name ↔ String
-
getter/setter pair
- price ↔ double
-
getter/setter pair
- priceDisplay → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJSON(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJsonDefault(
Map< String, dynamic> json) → ProfileSkill