Tip class

Constructors

Tip({String id = '', String senderId = '', String senderName = '', String senderAvatarUrl = '', String recipientId = '', String recipientName = '', TipTier tier = TipTier.cafe, double amount = 0, String? message, String? contextType, String? contextId, int createdTime = 0})
Tip.fromJSON(dynamic data)

Properties

amount double
getter/setter pair
contextId String?
getter/setter pair
contextType String?
getter/setter pair
createdTime int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
message String?
getter/setter pair
recipientId String
getter/setter pair
recipientName String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
senderAvatarUrl String
getter/setter pair
senderId String
getter/setter pair
senderName String
getter/setter pair
tier TipTier
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited