UserSubscription class

Constructors

UserSubscription({String subscriptionId = '', String userId = '', SubscriptionLevel? level, Price? price, SubscriptionStatus? status, int startDate = 0, int endDate = 0, CancellationReason? endReason})
UserSubscription.fromJSON(Map<String, dynamic> data)

Properties

endDate ↔ int
getter/setter pair
endReason ↔ CancellationReason?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
level ↔ SubscriptionLevel?
getter/setter pair
price ↔ Price?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startDate ↔ int
getter/setter pair
status ↔ SubscriptionStatus?
getter/setter pair
subscriptionId ↔ String
getter/setter pair
userId ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited