BlogEntry class

Constructors

BlogEntry({required String id, required DateTime date, required String slug, required String title, required String content, required String excerpt, String author = '', String url = '', String imgUrl = ''})
BlogEntry.fromHtml(Element article)
Crea una instancia de BlogEntry a partir de un elemento HTML que representa un post.
factory
BlogEntry.fromJson(Map<String, dynamic> json)
Creates a BlogEntry instance from JSON.
factory

Properties

author → String
final
content → String
final
date → DateTime
final
excerpt → String
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
imgUrl → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slug → String
final
title → String
final
url → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts this BlogEntry instance to JSON.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited