AudioHandlerService class abstract

Constructors

AudioHandlerService()

Properties

hashCode int
The hash code for this object.
no setterinherited
isPlaying bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speed → ValueStream<double>
no setter
stoppedByVideo bool
getter/setter pair
volume → ValueStream<double>
no setter

Methods

moveQueueItem(int currentIndex, int newIndex) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() Future<void>
play() Future<void>
setVolume(double volume) Future<void>
stop() Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited