EventService class abstract

Constructors

EventService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addActivity(int index) → void
addAppMediaItem(AppMediaItem appMediaItem) → void
addCollectivesToFestival() → void
addCollectiveToFestival(Collective collective) → void
addEventImage() → void
addInfoToEvent() → void
addInstrument(int index) → void
addInvitedProfile(AppProfile mate, Instrument instr) → void
addItemsToEvent() → void
createEvent() Future<void>
createInstrumentFulfillment() → void
createPostEvent() Future<void>
filterEventsBy({EventType? eventType}) → void
getEventPlace(BuildContext context) Future<void>
gotoCollectiveDetails(Collective collective) → void
gotoEventSummary() → void
goWithFlyer() → void
isAlreadyInvited(String profileId) bool
lookupForMusicians() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeActivity(int index) → void
removeAppMediaItem(AppMediaItem appMediaItem) → void
removeCollectiveFromFestival(Collective collective) → void
removeInstrument(int index) → void
retrieveEvents() → void
sendCollectiveEventRequest(String collectiveId) Future<void>
sendProfileEventInvitations() Future<void>
sendProfileInvitation(AppProfile mate, Instrument inst) Future<void>
setCoverFree() → void
setCurrency(String chosenCurrency) → void
setDefaultNameDesc() → void
setEventDate(DateTime date) → void
setEventDesc() → void
setEventMaxDistance() → void
setEventName() → void
setEventTime(BuildContext context) → void
setEventType(EventType eventType) → void
setInstrumentToFulfill({String selectedInstr = ""}) → void
setIsOnlineCheckboxState() → void
setMessage(String text) → void
setOnlineEvent() → void
setPaymentAmount() → void
setReason(UsageReason reason) → void
setSelectedCollective(Collective selectedCollective) → void
setVocalTypeToFulfill(String vocalType) → void
toString() String
A string representation of this object.
inherited
updateEventDate(DateTime dateTime) → void
updateEventType(EventType eventType) → void
validateInfo() bool
validateNameDesc() bool

Operators

operator ==(Object other) bool
The equality operator.
inherited