MapsService class abstract
- Implementers
Constructors
Properties
- googleMapController ↔ GoogleMapController?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
markers
→ Set<
Marker> -
no setter
- placePosition → Position
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getCameraPosition(
Position position) → CameraPosition -
goToHomePosition(
) → Future< void> -
goToPosition(
Position placePosition) → Future< void> -
initialCameraPosition(
) → CameraPosition -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onError(
PlacesAutocompleteResponse response) → void -
placeAutoComplete(
BuildContext context, String startText) → Future< Prediction> -
predictionToGooglePlace(
Prediction prediction) → Future< Place> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited