MiniPlayerService class abstract

Constructors

MiniPlayerService()

Properties

hashCode int
The hash code for this object.
no setterinherited
isActive bool
Whether the miniplayer is currently visible (has an active media item).
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

goToMusicPlayerHome() → void
goToTimeline(BuildContext context) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
positionSlider({bool isPreview = false}) StreamBuilder<Duration>
setAppMediaItem(AppMediaItem appMediaItem) Future<void>
setIsTimeline(bool value) → void
setShowInTimeline({bool value = true}) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited