isSaiaLaunchActive static method

bool isSaiaLaunchActive()

Saia launch master check. Returns true if Saia as a product is active at all (regardless of per-feature tiers). Useful for the main entry point of the Saia experience in the drawer/sidebar.

Implementation

static bool isSaiaLaunchActive() {
  if (isAdmin) return true;
  return earlyAccessEnabled;
}