CoreConstants class

Constructors

CoreConstants()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

appItemSize List<String>
final
blogTabs List<String>
final
walletTabs List<String>
final

Constants

activityFeedLimit → const int
adminMaxVideoDurationInSeconds → const int
appBank → const String
appBot → const String
appBotName → const String
appItemQuotation → const String
articlesFeedTurn → const int
audioExtensions → const List<String>
blogMinWords → const int
booksFeedTurn → const int
cameraPositionZoom → const double
customPreset → const String
de → const String
dev → const String
digitalLibrary → const String
directoryLimit → const int
diverseTimelineLimit → const int
documentExtensions → const List<String>
emailMaximumLength → const int
en → const String
errorCreatingAccount → const String
errorRetrievingProfiles → const String
errorSigningOut → const String
es → const String
eventsLimit → const int
fifthHomeTabIndex → const int
firstChamberPreset → const String
firstHomeTabIndex → const int
firstReleaseYear → const int
firstYearDOB → const int
followerProfilesLimit → const int
followingProfilesLimit → const int
forthHomeTabIndex → const int
fr → const String
gamesFeedTurn → const int
goingTab → const String
grid → const String
http → const String
imageExtensions → const List<String>
imageMaxHeight → const int
imageMaxWidth → const int
Max image dimension (width or height) before upload. Images are resized to fit.
imageQuality → const int
Image compression quality (0-100). 80 = ~80% size reduction with minimal visible loss.
initialTimeSeconds → const String
itemTab → const String
km → const String
lastYearDOB → const int
listCategory → const List<String>
mainItemFeedTurn → const int
matesLimit → const int
maxAudioDuration → const int
maxEventNameDescLength → const int
maxEventNameLength → const int
maxLocationNameLength → const int
maxPlaceNameLength → const int
maxVideoFileSize → const int
maxVideosPerWeek → const int
monthNames → const Map<int, String>
myFavorites → const String
nameMinimumLength → const int
nextTimelineLimit → const int
passwordMaximumLength → const int
passwordMinimumLength → const int
phoneNotAvailable → const String
playbackRates → const List<double>
prevVersion1 → const String
prevVersion2 → const String
prevVersion3 → const String
prevVersion4 → const String
profileImageMaxHeight → const int
profileImageMaxWidth → const int
Profile/avatar image max dimension (smaller for avatars).
profilePostsLimit → const int
profilesLimit → const int
quotation → const String
recentTimelineLimit → const int
referenceId → const String
secondaryItemFeedTurn → const int
secondHomeTabIndex → const int
significantDistanceKM → const int
somewhereUniverse → const String
sponsorsFeedTurn → const int
sponsorsLimit → const int
spotify → const String
thirdHomeTabIndex → const int
thumbnailQuality → const int
Thumbnail quality for video previews and small images.
timeAgoPattern → const String
timelineLimit → const int
titleTextDivider → const String
transparentImageBase64 → const String
updatePhone → const String
updateProfileType → const String
updateProfileTypeSuccess → const String
userMaxVideoDurationInSeconds → const int
usernameMaximumLength → const int
usernameMinimumLength → const int
verifiedMaxVideoDurationInSeconds → const int
videoExtensions → const List<String>
videoThumbnailQuality → const int
Video thumbnail quality (used by VideoCompress).
wifi → const String
youtube → const String
yyyyMMddHHmm → const String