AppHiveBox enum

Inheritance
Available extensions

Values

settings → const AppHiveBox
const AppHiveBox(false)
timeline → const AppHiveBox
const AppHiveBox(false)
releases → const AppHiveBox
const AppHiveBox(true)
player → const AppHiveBox
const AppHiveBox(true)
downloads → const AppHiveBox
const AppHiveBox(false)
pdfCache → const AppHiveBox
const AppHiveBox(false)
mp3Cache → const AppHiveBox
const AppHiveBox(false)
stats → const AppHiveBox
const AppHiveBox(false)
favoriteItems → const AppHiveBox
const AppHiveBox(false)
directory → const AppHiveBox
const AppHiveBox(false)
nupale → const AppHiveBox
const AppHiveBox(false)
casete → const AppHiveBox
const AppHiveBox(false)
profile → const AppHiveBox
const AppHiveBox(false)
games → const AppHiveBox
const AppHiveBox(false)
blog → const AppHiveBox
const AppHiveBox(false)
posts → const AppHiveBox
const AppHiveBox(true)
visitedProfiles → const AppHiveBox
const AppHiveBox(true)
inbox → const AppHiveBox
const AppHiveBox(false)
syncQueue → const AppHiveBox
const AppHiveBox(false)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
limit → bool
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<AppHiveBox>
A constant List of the values in this enum, in order of their declaration.