AppInUse enum
Values
- a → const AppInUse
- b → const AppInUse
- c → const AppInUse
- d → const AppInUse
- e → const AppInUse
- f → const AppInUse
- g → const AppInUse
- h → const AppInUse
- i → const AppInUse
- j → const AppInUse
- k → const AppInUse
- l → const AppInUse
- m → const AppInUse
- n → const AppInUse
- o → const AppInUse
- p → const AppInUse
- q → const AppInUse
- r → const AppInUse
- s → const AppInUse
- t → const AppInUse
- u → const AppInUse
- v → const AppInUse
- w → const AppInUse
- x → const AppInUse
- y → const AppInUse
- z → const AppInUse
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited