PageContentRegistry class

Global registry for the content currently visible on screen.

Any module can call register when its page loads to make the content available for AI assistants (like Itzli) without creating a dependency on neom_ia. The AI module reads this registry to understand what the user is looking at.

Usage:

// On page load:
PageContentRegistry.register(
  route: '/blog/abc123',
  title: 'Roto',
  body: 'El no esta muerto, Llora con ciertas canciones...',
  author: 'Fcrown',
  contentType: 'blog_entry',
);

// On page dispose:
PageContentRegistry.clear();

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

author String
getter/setter pair
body String
getter/setter pair
contentType String
getter/setter pair
hasContent bool
Whether there is active content registered.
no setter
metadata Map<String, String>
getter/setter pair
registeredAt int
getter/setter pair
route String
getter/setter pair
title String
getter/setter pair

Static Methods

clear() → void
Clear registered content.
register({required String route, required String title, String body = '', String author = '', String contentType = '', Map<String, String> metadata = const {}}) → void
Register the visible page content.