utils/platform/core_geocoding_io library

Classes

Location
Contains detailed location information.
Placemark
Contains detailed placemark information.

Functions

locationFromAddress(String address) Future<List<Location>>
Returns a list of Location instances found for the supplied address.
placemarkFromCoordinates(double latitude, double longitude) Future<List<Placemark>>
Returns a list of Placemark instances found for the supplied coordinates.