utils/platform/core_io_io library

Classes

Directory
A reference to a directory (or folder) on the file system.
File
A reference to a file on the file system.
Platform
Information about the environment in which the current program is running.
Process
The means to execute a program.
ProcessResult
The result of running a non-interactive process started with Process.run or Process.runSync.

Functions

exit(int code) → Never
Exit the Dart VM process immediately with the given exit code.