PositionUtilities class

Constructors

PositionUtilities()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

distanceBetweenPositions(Position mainUserPos, Position refUserPos) → double
distanceBetweenPositionsRounded(Position mainUserPos, Position refUserPos) → int
getAddressesFromPositions(List<Position> positions) → Future<List<String>>
getAddressFromFormattedAddress(String formattedAddress) → Future<Address>
getAddressFromPosition(Position position) → Future<Address>
getFormattedAddressFromPosition(Position position) → Future<String>
getLocationSuggestions(Position position, {bool includeCurrentPosition = true}) → Future<List<String>>