SlugMatch class

Result of resolving a slug — type-safe like GoRouterState.

Constructors

SlugMatch({required String type, required String id, required String slug, dynamic entity})
const

Properties

entity → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slug String
final
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited