onInit method
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
Implementation
@override
void onInit() {
super.onInit();
AppConfig.logger.t("onInit Mate Controller");
try {
profile = userServiceImpl.profile;
if(Sint.arguments != null && Sint.arguments is List<String>) {
if(Sint.arguments.isNotEmpty) {
mateIds = Sint.arguments;
}
}
loadMateProfiles();
} catch (e, st) {
NeomErrorLogger.recordError(e, st, module: 'neom_core', operation: 'onInit');
}
}