FanSessionData class
Raw session data for fan segmentation input
Constructors
- FanSessionData({required String itemId, required int engagement, required String monthKey})
-
const
Properties
- engagement → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemId → String
-
final
- monthKey → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited