NeomVisualState class

Constructors

NeomVisualState({required double phase, required double amplitude, required double pan, required double breath, required double modulation, required double neuro, double frequency = 0})
const

Properties

amplitude double
final
breath double
final
frequency double
final
hashCode int
The hash code for this object.
no setterinherited
modulation double
final
neuro double
final
pan double
final
phase double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

zero() NeomVisualState