SubscriptionPlan class
Constructors
- SubscriptionPlan({String id = '', String name = '', String imgUrl = '', String href = '', String productId = '', String priceId = '', String priceIdYearly = '', SubscriptionLevel? level, Price? price, Price? priceYearly, bool isActive = true, bool isLive = true, double? discount = 0.0, DateTime? lastUpdated, String founderTier = '', int founderSeatsTotal = 0, int founderSeatsRemaining = 0})
- SubscriptionPlan.fromJSON(dynamic data)
Properties
- discount ↔ double?
-
Yearly price (resolved from Stripe, optional)
getter/setter pair
- founderSeatsRemaining ↔ int
-
getter/setter pair
- founderSeatsTotal ↔ int
-
getter/setter pair
- founderTier ↔ String
-
Founder program (optional). When
founderTieris non-empty, the UI shows a "remaining seats" counter and the plan is marketed as lifetime. Values: 'obsidiana' | 'cuarzo' | 'amatista' | 'turquesa' | 'jade'.getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- href ↔ String
-
getter/setter pair
- id ↔ String
-
getter/setter pair
- imgUrl ↔ String
-
getter/setter pair
- isActive ↔ bool
-
getter/setter pair
- isFounderPlan → bool
-
no setter
- isLive ↔ bool
-
getter/setter pair
- lastUpdated ↔ DateTime?
-
getter/setter pair
- level ↔ SubscriptionLevel?
-
Stripe Price Id for yearly billing (optional)
getter/setter pair
- name ↔ String
-
getter/setter pair
- price ↔ Price?
-
getter/setter pair
- priceId ↔ String
-
Stripe Product Id
getter/setter pair
- priceIdYearly ↔ String
-
Stripe Price Id (monthly by convention)
getter/setter pair
- priceYearly ↔ Price?
-
Monthly price (resolved from Stripe)
getter/setter pair
- productId ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJSON(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited