WithdrawalRequest class
Constructors
- WithdrawalRequest({String id = '', String ownerEmail = '', double appCoinsAmount = 0.0, double mxnAmount = 0.0, String bankClabe = '', WithdrawalStatus status = WithdrawalStatus.pending, int createdTime = 0, int processedTime = 0, String adminNote = ''})
- WithdrawalRequest.fromJSON(dynamic json)
-
factory
Properties
- adminNote ↔ String
-
getter/setter pair
- appCoinsAmount ↔ double
-
getter/setter pair
- bankClabe ↔ String
-
Equivalent in MXN
getter/setter pair
- createdTime ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String
-
getter/setter pair
- mxnAmount ↔ double
-
Amount in AppCoins to withdraw
getter/setter pair
- ownerEmail ↔ String
-
getter/setter pair
- processedTime ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ WithdrawalStatus
-
CLABE interbancaria
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJSON(
) → Map< String, dynamic> -
toString(
) → String -
Note from admin if rejected
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited