CloudDriveService class abstract
Abstract interface for cloud drive operations (SAIA-facing).
Simplified interface for AI assistant consumption. Implemented by neom_cloud's GoogleDriveController. Consumed by neom_ia (SAIA) via Sint DI.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAuthenticated → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
- Get a shareable link for a file.
-
listDriveFiles(
{int limit = 20}) → Future< List< Map< >String, dynamic> > - List files from the user's cloud drive.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited