CloudEmailService class abstract
Abstract interface for cloud email operations.
Implemented by neom_cloud's GoogleGmailController. Consumed by neom_ia (SAIA), neom_erp, etc. via Sint DI.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAuthenticated → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createDraft(
{required String to, required String subject, required String body}) → Future< String> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendEmail(
{required String to, required String subject, required String body}) → Future< bool> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited