DeferredLoader class

Wrapper that loads a deferred library before rendering its child.

Used with Dart's deferred as imports to enable code splitting on web. The WASM/JS compiler splits each deferred import into a separate chunk (.part.wasm / .part.js) that is only downloaded when libraryLoader is called — i.e. when the user first navigates to the route that uses this widget.

On native platforms (iOS, Android, macOS, Windows, Linux), libraryLoader resolves instantly (no-op) so this widget is transparent.

Usage in a module's *_routes.dart:

import 'package:neom_core/ui/deferred_loader.dart';
import 'ui/erp_dashboard_page.dart' deferred as erp_dash;

class ErpRoutes {
  static List<SintPage> get routes => [
    SintPage(
      name: '/erp',
      page: () => DeferredLoader(
        erp_dash.loadLibrary,
        () => erp_dash.ErpDashboardPage(),
      ),
    ),
  ];
}
Inheritance

Constructors

DeferredLoader(Future<void> libraryLoader(), Widget builder(), {Key? key})
const

Properties

builder Widget Function()
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
libraryLoader Future<void> Function()
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited