UserRole enum

User Roles for administration purposes

Inheritance
Available extensions

Values

subscriber → const UserRole
const UserRole(0)
editor → const UserRole
const UserRole(1)
support → const UserRole
const UserRole(2)
erp → const UserRole

ERP / Laboral — financial monitoring and business intelligence access

const UserRole(3)
developer → const UserRole
const UserRole(4)
admin → const UserRole
const UserRole(5)
superAdmin → const UserRole
const UserRole(6)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<UserRole>
A constant List of the values in this enum, in order of their declaration.